@@ -174,8 +174,8 @@ func PlatformBasedOCConsoleCLIDownloads(host, cliDownloadsName string) *v1.Conso
 		{"Mac for x86_64", "amd64/mac", "oc.zip"},
 		{"Windows for x86_64", "amd64/windows", "oc.zip"},
 		{"Linux for ARM 64 (unsupported)", "arm64/linux", "oc.tar"},
-		{"Linux for IBM Power, little endian (unsupported)", "ppc64le/linux", "oc.tar"},
-		{"Linux for IBM Z (unsupported)", "s390x/linux", "oc.tar"},
+		{"Linux for IBM Power, little endian", "ppc64le/linux", "oc.tar"},
+		{"Linux for IBM Z", "s390x/linux", "oc.tar"},
 	}
 
 	links := []v1.CLIDownloadLink{}
