@@ -3,13 +3,15 @@ package e2e
 import (
 	"testing"
 
+	operatorsv1 "github.com/openshift/api/operator/v1"
+	"github.com/openshift/console-operator/pkg/api"
 	"github.com/openshift/console-operator/test/e2e/framework"
 )
 
-func setupUnmanagedTestCase(t *testing.T) *framework.ClientSet {
-	client := framework.MustNewClientset(t, nil)
+func setupUnmanagedTestCase(t *testing.T) (*framework.ClientSet, *operatorsv1.Console) {
+	client, operatorConfig := framework.StandardSetup(t)
 	framework.MustUnmanageConsole(t, client)
-	return client
+	return client, operatorConfig
 }
 
 func cleanUpUnmanagedTestCase(t *testing.T, client *framework.ClientSet) {
@@ -19,7 +21,7 @@ func cleanUpUnmanagedTestCase(t *testing.T, client *framework.ClientSet) {
 // TestUnmanaged() sets ManagementState:Unmanaged then deletes a set of console
 // resources and verifies that the operator does not recreate them.
 func TestUnmanaged(t *testing.T) {
-	client := setupUnmanagedTestCase(t)
+	client, _ := setupUnmanagedTestCase(t)
 	defer cleanUpUnmanagedTestCase(t, client)
 
 	framework.DeleteAll(t, client)
@@ -31,7 +33,7 @@ func TestUnmanaged(t *testing.T) {
 }
 
 func TestEditUnmanagedConfigMap(t *testing.T) {
-	client := setupUnmanagedTestCase(t)
+	client, _ := setupUnmanagedTestCase(t)
 	defer cleanUpUnmanagedTestCase(t, client)
 
 	err := patchAndCheckConfigMap(t, client, false)
@@ -41,7 +43,7 @@ func TestEditUnmanagedConfigMap(t *testing.T) {
 }
 
 func TestEditUnmanagedService(t *testing.T) {
-	client := setupUnmanagedTestCase(t)
+	client, _ := setupUnmanagedTestCase(t)
 	defer cleanUpUnmanagedTestCase(t, client)
 
 	err := patchAndCheckService(t, client, false)
@@ -51,7 +53,7 @@ func TestEditUnmanagedService(t *testing.T) {
 }
 
 func TestEditUnmanagedRoute(t *testing.T) {
-	client := setupUnmanagedTestCase(t)
+	client, _ := setupUnmanagedTestCase(t)
 	defer cleanUpUnmanagedTestCase(t, client)
 
 	err := patchAndCheckRoute(t, client, false)
@@ -59,3 +61,18 @@ func TestEditUnmanagedRoute(t *testing.T) {
 		t.Fatalf("error: %s", err)
 	}
 }
+
+func TestEditUnmanagedConsoleCLIDownloads(t *testing.T) {
+	client, _ := setupUnmanagedTestCase(t)
+	defer cleanUpUnmanagedTestCase(t, client)
+
+	err := patchAndCheckConsoleCLIDownloads(t, client, false, api.OCCLIDownloadsCustomResourceName)
+	if err != nil {
+		t.Fatalf("error: %s", err)
+	}
+
+	err = patchAndCheckConsoleCLIDownloads(t, client, false, api.ODOCLIDownloadsCustomResourceName)
+	if err != nil {
+		t.Fatalf("error: %s", err)
+	}
+}
